@@ -3,6 +3,8 @@ import logging
 
 from django.conf import settings
 from django.views import View
+from django.views.decorators.csrf import csrf_exempt
+from django.utils.decorators import method_decorator
 
 try:
     from webargs import ValidationError
@@ -14,7 +16,7 @@ from .exceptions import Unauthorized
 from .request import Request
 from .response import APIResponse
 
-logger = logging.getLogger('django.views')
+logger = logging.getLogger(__name__)
 
 
 class APIView(View):
@@ -37,6 +39,7 @@ class APIView(View):
     def _dispatch(self, request, *args, **kwargs):
         return super().dispatch(request, *args, **kwargs)
 
+    @method_decorator(csrf_exempt)
     def dispatch(self, request, *args, **kwargs):
         self.request = request = Request(raw_request=request)
         try:
@@ -54,23 +57,31 @@ class APIView(View):
         if isinstance(exc, ValidationError):
             return APIResponse(exc.messages,
                                status_code=HTTPStatus.UNPROCESSABLE_ENTITY)
+        self.log_exception(request, exc)
+
+        msg = getattr(exc, 'user_hint', 'internal_error')
+        status_code = getattr(exc, 'status_code',
+                              HTTPStatus.INTERNAL_SERVER_ERROR)
+        return APIResponse(msg, status_code=status_code)
+
+    def log_exception(self, request, exc):
         context = {
             'method': request.method,
             'path': request.path,
             'query_params': request.query_params,
             'data': request.data,
         }
-        if not isinstance(exc, Unauthorized):
+        try:
             context['user'] = request.user
+        except Exception:
+            # must import after django setup
+            from django.contrib.auth.models import AnonymousUser
+            context['user'] = AnonymousUser
         context['exc'] = exc
         level = getattr(exc, 'logging_level', logging.ERROR)
         extra_option = {}
-        if level > logging.ERROR:
+        if level >= logging.ERROR:
             extra_option['exc_info'] = True
         log_content = ' '.join(f'[{key}: {value}]'
                                for key, value in context.items())
         self.logger.log(level, log_content, **extra_option)
-        msg = getattr(exc, 'user_hint', 'internal_error')
-        status_code = getattr(exc, 'status_code',
-                              HTTPStatus.INTERNAL_SERVER_ERROR)
-        return APIResponse(msg, status_code=status_code)
